@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.5';
 
 
 1;
@@ -19,13 +19,14 @@ Perl::Critic::CognitiveComplexity - Cognitive Complexity, Because Testability !=
 
 Perl::Critic::Policy::CognitiveComplexity::ProhibitExcessCognitiveComplexity is a rule that checks the
 cognitive complexity score of your subroutines. It is based on a new scoring algorithm introduced by
-SonarSource. See https://blog.sonarsource.com/cognitive-complexity-because-testability-understandability/
+SonarSource. See L<SonarSource blog entry|https://blog.sonarsource.com/cognitive-complexity-because-testability-understandability/>.
 
 =head2 Rules
 
 =over 1
 
-=item L<CognitiveComplexity::ProhibitExcessCognitiveComplexity|Perl::Critic::Policy::CognitiveComplexity::ProhibitExcessCognitiveComplexity> - Avoid code that is nested, and thus difficult to grasp.
+=item L<CognitiveComplexity::ProhibitExcessCognitiveComplexity|Perl::Critic::Policy::CognitiveComplexity::ProhibitExcessCognitiveComplexity> - Avoid code that is nested, and thus difficult to grasp. 
+Examples can be seen in the Policy POD.
 
 =back
 
